# Gemini Chat App

**Gemini Chat App** is an application which allows users to chat with Google Gemini AI. The chat app
uses Graphical User Interface (GUI).

# Source Code

The source code of **Gemini Chat App** is available in [Source Code](https://github.com/SoftwareApkDev/gemini_chat_app/blob/master/gemini_chat_app/gemini_chat_app.py).

# Installation

```
pip install gemini_chat_app
```

# How to Run the Application?

Pre-requisites:

1. [Python](https://www.python.org/downloads/) installed in your device.
2. .env file in the same directory as <GEMINI_CHAT_APP_DIRECTORY> and has the value of GEMINI_API_KEY.

```
cd <GEMINI_CHAT_APP_DIRECTORY>
python3 gemini_chat_app.py
```

**Note:** Replace <GEMINI_CHAT_APP_DIRECTORY> with the path to the directory of the application **Gemini Chat App**.

Then, the application will start like as follows.

![App Start](images/App_Start.png)

Below shows what happens once you sent a prompt.

![Prompt Sent](images/Prompt_Sent.png)
